# eric7.WebBrowser.WebBrowserArgumentsCreator

Module implementing a function to create an argparse.Namespace object for the web browser.

### Global Attributes

None

### Classes

None

### Functions

createArgparseNamespace | Function to create an argparse.Namespace object.

## createArgparseNamespace

createArgparseNamespace(argv=None)

Function to create an argparse.Namespace object.

argv (list of str)
  list of command line arguments to be parsed

Return:
  created argument parser object

Return Type:
  argparse.ArgumentParser

Up